@@ -2,16 +2,9 @@ mi.completed.default <- function(object, m = 1){
   if( m(object) < m ) { 
     stop( message = "Index of imputation is not within the range." ) 
   }
-  if(object@preprocess){
-    info <- object@mi.info.preprocessed
-    miMatrix <- data.mi(object)
-    miMatrix <- mi.preprocess(miMatrix, info=object@mi.info)$data
-  }
-  else{
-    info <- info.mi(object)
-    miMatrix <- data.mi(object)
-  }
-  
+  info <- info.mi(object)
+  miMatrix <- data.mi(object)
+    
   # changed to check if var was included (DS)
   mis.name <- names(info)[.nmis(info) > 0 & !.all.missing(info)& .include(info)]
 
@@ -25,17 +18,15 @@ mi.completed.default <- function(object, m = 1){
 
 
 
-setMethod("mi.completed", signature( object = "mi" ),
+setMethod("mi.completed", signature(object = "mi"),
   function (object) {
     n.chains <- m(object)
     data <- vector("list", n.chains)
     for(i in 1:m(object)){
       data[[i]] <- mi.completed.default(object, m = i) 
     }
-    if(object@preprocess){
-      info <- object@mi.info.preprocessed
-      data <- mi.postprocess(data, info)
-    }
+    info <- object@mi.info
+    data <- mi.postprocess(data, info)
     return(data)
   }
 )
@@ -45,13 +36,8 @@ setMethod("mi.completed", signature( object = "mi" ),
 
 setMethod("mi.data.frame", signature( object = "mi" ),
   function (object, m = 1) {
-    if(object@preprocess){
-      data <- mi.completed.default(object, m=m)
-      data <- mi.postprocess(data, info=object@mi.info.preprocessed)
-    }
-    else{
-      data <- mi.completed.default(object, m = m) 
-    }
+    data <- mi.completed.default(object, m=m)
+    data <- mi.postprocess(data, info=object@mi.info)
     return(data)
   }
 )
